@@ -1,7 +1,8 @@
 from django.urls import path, re_path
 
-import mentions.views.names as view_names
+from mentions.views import view_names
 from mentions.views.webmention import GetWebmentionsView, WebmentionView
+from tests.views import TemplateTagTestView
 
 """
 /webmention/
@@ -11,16 +12,18 @@ e.g.
     urlpatterns = [
         ...,
         path(r'webmention/', include('mentions.urls')),
-        ...,
     ]
 """
 urlpatterns = [
-    path(
-        '',
-        WebmentionView.as_view(),
-        name=view_names.webmention_api_incoming),
+    path("", WebmentionView.as_view(), name=view_names.webmention_api_incoming),
     re_path(
-        r'^get/?$',
+        r"^get/?$",
         GetWebmentionsView.as_view(),
-        name=view_names.webmention_api_get_for_object),
+        name=view_names.webmention_api_get_for_object,
+    ),
+    path(
+        "templatetagstest",
+        TemplateTagTestView.as_view(),
+        name="test-template-tags",
+    ),
 ]
